sccoda.model package
====================

Submodules
----------

sccoda.model.dirichlet\_models module
-------------------------------------

.. automodule:: sccoda.model.dirichlet_models
   :members:
   :undoc-members:
   :show-inheritance:

sccoda.model.other\_models module
---------------------------------

.. automodule:: sccoda.model.other_models
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: sccoda.model
   :members:
   :undoc-members:
   :show-inheritance:
